@@ -28,7 +28,8 @@ from rpcerror import (
 )
 from rpclib import (
     JsonRpc,
-    rpcmethod
+    rpcmethod,
+    ServiceMethod
 )
 
 
